==> samba-4.12.3-2-x86_64.pkg.tar.zst: usr/share/ctdb/tests/scripts/script_install_paths.sh <==
# Hey Emacs, this is a -*- shell-script -*- !!!  :-)

if ! $CTDB_TESTS_ARE_INSTALLED ; then
	if [ ! -f "${CTDB_TEST_DIR}/run_tests.sh" ] ; then
		die "Tests not installed but can't find run_tests.sh"
	fi

	ctdb_dir=$(dirname "$CTDB_TEST_DIR")

	top_dir=$(cd -P "$ctdb_dir" && echo "$PWD") # real path
	if [ ! -d "${top_dir}/bin" ] ; then
		top_dir=$(dirname "$top_dir")
	fi

	CTDB_SCRIPTS_BASE="${ctdb_dir}/config"
	CTDB_SCRIPTS_INIT_SCRIPT="${ctdb_dir}/config/ctdb.init"
	CTDB_SCRIPTS_SBIN_DIR="${ctdb_dir}/config"
	CTDB_SCRIPTS_TOOLS_BIN_DIR="${ctdb_dir}/tools"
	CTDB_SCRIPTS_TOOLS_HELPER_DIR="${ctdb_dir}/tools"
	CTDB_SCRIPTS_HELPER_BINDIR="${top_dir}/bin"
	CTDB_SCRIPTS_DATA_DIR="${ctdb_dir}/config"
	CTDB_SCRIPTS_TESTS_LIBEXEC_DIR="${top_dir}/bin"
	CTDB_SCRIPTS_TESTS_BIN_DIR="$CTDB_TEST_DIR"
else
	# Installed
	CTDB_SCRIPTS_BASE="/etc/ctdb"
	CTDB_SCRIPTS_INIT_SCRIPT="" # No ideas here... this is a packaging choice
	CTDB_SCRIPTS_SBIN_DIR="/usr/bin"
	CTDB_SCRIPTS_TOOLS_BIN_DIR="/usr/bin"
	CTDB_SCRIPTS_TOOLS_HELPER_DIR="/usr/lib/samba/ctdb"
	CTDB_SCRIPTS_HELPER_BINDIR="/usr/lib/samba/ctdb"
	CTDB_SCRIPTS_DATA_DIR="/usr/share/ctdb"
	CTDB_SCRIPTS_TESTS_LIBEXEC_DIR="/usr/lib/samba/ctdb/tests"
	CTDB_SCRIPTS_TESTS_BIN_DIR="/usr/bin"
fi

export CTDB_SCRIPTS_BASE \
       CTDB_SCRIPTS_BIN_DIR \
       CTDB_SCRIPTS_INIT_SCRIPT \
       CTDB_SCRIPTS_SBIN_DIR \
       CTDB_SCRIPTS_TOOLS_BIN_DIR \
       CTDB_SCRIPTS_TOOLS_HELPER_DIR \
       CTDB_SCRIPTS_HELPER_BINDIR \
       CTDB_SCRIPTS_DATA_DIR \
       CTDB_SCRIPTS_TESTS_LIBEXEC_DIR \
       CTDB_SCRIPTS_TESTS_BIN_DIR

==> samba-4.13.4-1-x86_64.pkg.tar.zst: usr/share/ctdb/tests/scripts/script_install_paths.sh <==
# Hey Emacs, this is a -*- shell-script -*- !!!  :-)

# Sets $bin_dir
find_bin_dir ()
{
	_ctdb_dir="$1"

	bin_dir="$(pwd -P)/bin"
	if [ -d "$(pwd -P)/bin" ] ; then
		return
	fi

	bin_dir="${_ctdb_dir}/bin"
	if [ -d "$bin_dir" ] ; then
		return
	fi

	bin_dir="$(dirname "${_ctdb_dir}")/bin"
	if [ -d "$bin_dir" ] ; then
		return
	fi

	die "Unable to locate bin/ subdirectory"
}


if ! $CTDB_TESTS_ARE_INSTALLED ; then
	if [ ! -f "${CTDB_TEST_DIR}/run_tests.sh" ] ; then
		die "Tests not installed but can't find run_tests.sh"
	fi

	ctdb_dir=$(cd -P "$(dirname "$CTDB_TEST_DIR")" && pwd) # real path

	find_bin_dir "$ctdb_dir"

	CTDB_SCRIPTS_BASE="${ctdb_dir}/config"
	CTDB_SCRIPTS_INIT_SCRIPT="${ctdb_dir}/config/ctdb.init"
	CTDB_SCRIPTS_SBIN_DIR="${ctdb_dir}/config"
	CTDB_SCRIPTS_TOOLS_BIN_DIR="${ctdb_dir}/tools"
	CTDB_SCRIPTS_TOOLS_HELPER_DIR="${ctdb_dir}/tools"
	CTDB_SCRIPTS_HELPER_BINDIR="$bin_dir"
	CTDB_SCRIPTS_DATA_DIR="${ctdb_dir}/config"
	CTDB_SCRIPTS_TESTS_LIBEXEC_DIR="$bin_dir"
	CTDB_SCRIPTS_TESTS_BIN_DIR="$CTDB_TEST_DIR"
else
	# Installed
	CTDB_SCRIPTS_BASE="/etc/ctdb"
	CTDB_SCRIPTS_INIT_SCRIPT="" # No ideas here... this is a packaging choice
	CTDB_SCRIPTS_SBIN_DIR="/usr/bin"
	CTDB_SCRIPTS_TOOLS_BIN_DIR="/usr/bin"
	CTDB_SCRIPTS_TOOLS_HELPER_DIR="/usr/lib/samba/ctdb"
	CTDB_SCRIPTS_HELPER_BINDIR="/usr/lib/samba/ctdb"
	CTDB_SCRIPTS_DATA_DIR="/usr/share/ctdb"
	CTDB_SCRIPTS_TESTS_LIBEXEC_DIR="/usr/lib/samba/ctdb/tests"
	CTDB_SCRIPTS_TESTS_BIN_DIR="/usr/bin"
fi

export CTDB_SCRIPTS_BASE \
       CTDB_SCRIPTS_BIN_DIR \
       CTDB_SCRIPTS_INIT_SCRIPT \
       CTDB_SCRIPTS_SBIN_DIR \
       CTDB_SCRIPTS_TOOLS_BIN_DIR \
       CTDB_SCRIPTS_TOOLS_HELPER_DIR \
       CTDB_SCRIPTS_HELPER_BINDIR \
       CTDB_SCRIPTS_DATA_DIR \
       CTDB_SCRIPTS_TESTS_LIBEXEC_DIR \
       CTDB_SCRIPTS_TESTS_BIN_DIR
